==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridCellEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { DataGridDescriptionMetadata } from "./DataGridDescriptionMetadata";
import { GridCellEventArgsDescription } from "./GridCellEventArgsDescription";
/**
 * @hidden
 */
export let GridCellEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridCellEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridCellEventArgsDescriptionMetadata.a == null) {
                GridCellEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridCellEventArgsDescriptionMetadata.c(GridCellEventArgsDescriptionMetadata.a);
            }
            if (a.j(GridCellEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridCellEventArgsDescriptionMetadata.a);
            CellInfoDescriptionMetadata.d(a);
            DataGridDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("CellInfo", "ExportedType:CellModel");
            a.item("Grid", "ExportedType:Grid");
            a.item("Button", "ExportedType:string:MouseButton");
            a.item("Button@names", "Left;Middle;Right;Unkown");
            a.item("IsDoubleClick", "Boolean");
        }
        static d(a) {
            GridCellEventArgsDescriptionMetadata.b(a);
            a.aa("GridCellEventArgs", () => new GridCellEventArgsDescription());
            a.z("GridCellEventArgs", GridCellEventArgsDescriptionMetadata.a);
        }
    }
    GridCellEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridCellEventArgsDescriptionMetadata, 'GridCellEventArgsDescriptionMetadata');
    GridCellEventArgsDescriptionMetadata.a = null;
    return GridCellEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridCellEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { DataGridDescriptionMetadata } from "./DataGridDescriptionMetadata";
import { GridCellEventArgsDescription } from "./GridCellEventArgsDescription";
/**
 * @hidden
 */
export let GridCellEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridCellEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridCellEventArgsDescriptionMetadata.a == null) {
                GridCellEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridCellEventArgsDescriptionMetadata.c(GridCellEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridCellEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridCellEventArgsDescriptionMetadata.a);
            CellInfoDescriptionMetadata.d(a);
            DataGridDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("CellInfo", "ExportedType:CellModel");
            a.item("Grid", "ExportedType:Grid");
            a.item("Button", "ExportedType:string:MouseButton");
            a.item("Button@names", "Left;Middle;Right;Unkown");
            a.item("IsDoubleClick", "Boolean");
        }
        static d(a) {
            GridCellEventArgsDescriptionMetadata.b(a);
            a.ac("GridCellEventArgs", () => new GridCellEventArgsDescription());
            a.ab("GridCellEventArgs", GridCellEventArgsDescriptionMetadata.a);
        }
    }
    GridCellEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridCellEventArgsDescriptionMetadata, 'GridCellEventArgsDescriptionMetadata');
    GridCellEventArgsDescriptionMetadata.a = null;
    return GridCellEventArgsDescriptionMetadata;
})();
